# Registries

::: harborapi.client.HarborAsyncClient
    options:
        members:
        - get_registry
        - create_registry
        - update_registry
        - delete_registry
        - get_registry_info
        - get_registry_adapters
        - get_registry_providers
        - check_registry_status
        - get_registries
